@@ -4,8 +4,8 @@ from typing import Dict, Any
 
 import pytest
 
-from pydantic_redis.shared.model.prop_utils import NESTED_MODEL_PREFIX
-from pydantic_redis.shared.utils import strip_leading
+from pydantic_redis._shared.model.prop_utils import NESTED_MODEL_PREFIX  # noqa
+from pydantic_redis._shared.utils import strip_leading  # noqa
 from pydantic_redis.asyncio import Model, RedisConfig
 from test.conftest import (
     async_redis_store_fixture,
