@@ -30,6 +30,13 @@ def test_benchmark_select_default(benchmark, store):
     benchmark(Book.select)
 
 
+@pytest.mark.parametrize("store", redis_store_fixture)
+def test_benchmark_select_default_paginated(benchmark, store):
+    """Benchmarks the select default operation when paginated"""
+    Book.insert(books)
+    benchmark(Book.select, skip=2, limit=2)
+
+
 @pytest.mark.parametrize("store", redis_store_fixture)
 def test_benchmark_select_columns(benchmark, store):
     """Benchmarks the select columns operation"""
@@ -37,6 +44,13 @@ def test_benchmark_select_columns(benchmark, store):
     benchmark(Book.select, columns=["title", "author", "in_stock"])
 
 
+@pytest.mark.parametrize("store", redis_store_fixture)
+def test_benchmark_select_columns_paginated(benchmark, store):
+    """Benchmarks the select columns operation, when paginated"""
+    Book.insert(books)
+    benchmark(Book.select, columns=["title", "author", "in_stock"], skip=2, limit=2)
+
+
 @pytest.mark.parametrize("store", redis_store_fixture)
 def test_benchmark_select_some_items(benchmark, store):
     """Benchmarks the select some items operation"""
